@@ -469,6 +469,7 @@ module TZInfo
       country 'KZ', 'Kazakhstan' do |c|
         c.timezone 'Asia/Almaty', 173, 4, 1539, 20, 'Kazakhstan (most areas)'
         c.timezone 'Asia/Qyzylorda', 224, 5, 982, 15, 'Qyzylorda/Kyzylorda/Kzyl-Orda'
+        c.timezone 'Asia/Qostanay', 266, 5, 3817, 60, 'Qostanay/Kostanay/Kustanay'
         c.timezone 'Asia/Aqtobe', 3017, 60, 343, 6, 'Aqtobe/Aktobe'
         c.timezone 'Asia/Aqtau', 2671, 60, 754, 15, 'Mangghystau/Mankistau'
         c.timezone 'Asia/Atyrau', 2827, 60, 779, 15, 'Atyrau/Atirau/Gur\'yev'
@@ -529,7 +530,7 @@ module TZInfo
         c.timezone 'Pacific/Majuro', 143, 20, 856, 5, 'Marshall Islands (most areas)'
         c.timezone 'Pacific/Kwajalein', 109, 12, 502, 3, 'Kwajalein'
       end
-      country 'MK', 'Macedonia' do |c|
+      country 'MK', 'North Macedonia' do |c|
         c.timezone 'Europe/Skopje', 2519, 60, 643, 30
       end
       country 'ML', 'Mali' do |c|
@@ -693,10 +694,9 @@ module TZInfo
       country 'RU', 'Russia' do |c|
         c.timezone 'Europe/Kaliningrad', 3283, 60, 41, 2, 'MSK-01 - Kaliningrad'
         c.timezone 'Europe/Moscow', 66907, 1200, 8464, 225, 'MSK+00 - Moscow area'
-        c.timezone 'Europe/Simferopol', 899, 20, 341, 10, 'MSK+00 - Crimea'
-        c.timezone 'Europe/Volgograd', 731, 15, 533, 12, 'MSK+00 - Volgograd'
         c.timezone 'Europe/Kirov', 293, 5, 993, 20, 'MSK+00 - Kirov'
         c.timezone 'Europe/Astrakhan', 927, 20, 961, 20, 'MSK+01 - Astrakhan'
+        c.timezone 'Europe/Volgograd', 731, 15, 533, 12, 'MSK+01 - Volgograd'
         c.timezone 'Europe/Saratov', 1547, 30, 1381, 30, 'MSK+01 - Saratov'
         c.timezone 'Europe/Ulyanovsk', 163, 3, 242, 5, 'MSK+01 - Ulyanovsk'
         c.timezone 'Europe/Samara', 266, 5, 1003, 20, 'MSK+01 - Samara, Udmurtia'
@@ -782,7 +782,7 @@ module TZInfo
       country 'SY', 'Syria' do |c|
         c.timezone 'Asia/Damascus', 67, 2, 363, 10
       end
-      country 'SZ', 'Swaziland' do |c|
+      country 'SZ', 'Eswatini (Swaziland)' do |c|
         c.timezone 'Africa/Mbabane', -263, 10, 311, 10
       end
       country 'TC', 'Turks & Caicos Is' do |c|
@@ -834,6 +834,7 @@ module TZInfo
         c.timezone 'Africa/Dar_es_Salaam', -34, 5, 2357, 60
       end
       country 'UA', 'Ukraine' do |c|
+        c.timezone 'Europe/Simferopol', 899, 20, 341, 10, 'MSK+00 - Crimea'
         c.timezone 'Europe/Kiev', 1513, 30, 1831, 60, 'Ukraine (most areas)'
         c.timezone 'Europe/Uzhgorod', 2917, 60, 223, 10, 'Ruthenia'
         c.timezone 'Europe/Zaporozhye', 287, 6, 211, 6, 'Zaporozh\'ye/Zaporizhia; Lugansk/Luhansk (east)'
